@@ -1,4 +1,4 @@
-library("testthat")
+library("testthat", exclude = "matches")
 library("ItemResponseTrees")
 
 test_check("ItemResponseTrees")
